summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorjason kirtland <jek@discorporate.us>2010-03-29 10:29:25 -0700
committerjason kirtland <jek@discorporate.us>2010-03-29 10:29:25 -0700
commitd1f55fb9d1a78213cef9dfaad153ca8a3bcbc0e3 (patch)
treef2e393cc2d97be9f05b2b845a46cd8c46e9f718c
parent8342f28502541e50e6b0f17b5cb3eeb22380c7ed (diff)
downloadblinker-d1f55fb9d1a78213cef9dfaad153ca8a3bcbc0e3.tar.gz
Added note about Jython compiler workaround in weakref test.
-rw-r--r--tests/test_signals.py10
1 files changed, 7 insertions, 3 deletions
diff --git a/tests/test_signals.py b/tests/test_signals.py
index ef02b4d..34a8fa3 100644
--- a/tests/test_signals.py
+++ b/tests/test_signals.py
@@ -81,9 +81,13 @@ def test_weak_receiver():
sig = blinker.Signal()
- # XXX: weirdly, under python an explicit weak=True causes this test
- # to fail, leaving a strong ref to the receiver somewhere. ?!!
- sig.connect(received) # weak=True by default.
+ # XXX: weirdly, under jython an explicit weak=True causes this test
+ # to fail, leaking a strong ref to the receiver somewhere.
+ # http://bugs.jython.org/issue1586
+ if jython:
+ sig.connect(received) # weak=True by default.
+ else:
+ sig.connect(received, weak=True)
del received
collect()